@@ -4,14 +4,14 @@ import (
 	"context"
 	"database/sql"
 	"fmt"
-	"github.com/google/uuid"
-	"github.com/jackc/pgtype"
-	"net"
+	"net/netip"
 	"strings"
 	"time"
 
-	"github.com/jackc/pgx/v4"
-	"github.com/jackc/pgx/v4/pgxpool"
+	"github.com/google/uuid"
+	"github.com/jackc/pgx/v5"
+	"github.com/jackc/pgx/v5/pgtype"
+	"github.com/jackc/pgx/v5/pgxpool"
 	"github.com/spf13/viper"
 	"github.com/turbot/go-kit/helpers"
 	"github.com/turbot/steampipe/pkg/constants"
@@ -26,7 +26,7 @@ import (
 
 // ExecuteSync implements Client
 // execute a query against this client and wait for the result
-func (c *DbClient) ExecuteSync(ctx context.Context, query string) (*queryresult.SyncQueryResult, error) {
+func (c *DbClient) ExecuteSync(ctx context.Context, query string, args ...any) (*queryresult.SyncQueryResult, error) {
 	// acquire a session
 	sessionResult := c.AcquireSession(ctx)
 	if sessionResult.Error != nil {
@@ -40,19 +40,19 @@ func (c *DbClient) ExecuteSync(ctx context.Context, query string) (*queryresult.
 	defer func() {
 		// we need to do this in a closure, otherwise the ctx will be evaluated immediately
 		// and not in call-time
-		sessionResult.Session.Close(utils.IsContextCancelled(ctx))
+		sessionResult.Session.Close(error_helpers.IsContextCanceled(ctx))
 	}()
-	return c.ExecuteSyncInSession(ctx, sessionResult.Session, query)
+	return c.ExecuteSyncInSession(ctx, sessionResult.Session, query, args...)
 }
 
 // ExecuteSyncInSession implements Client
 // execute a query against this client and wait for the result
-func (c *DbClient) ExecuteSyncInSession(ctx context.Context, session *db_common.DatabaseSession, query string) (*queryresult.SyncQueryResult, error) {
+func (c *DbClient) ExecuteSyncInSession(ctx context.Context, session *db_common.DatabaseSession, query string, args ...any) (*queryresult.SyncQueryResult, error) {
 	if query == "" {
 		return &queryresult.SyncQueryResult{}, nil
 	}
 
-	result, err := c.ExecuteInSession(ctx, session, query, nil)
+	result, err := c.ExecuteInSession(ctx, session, nil, query, args...)
 	if err != nil {
 		return nil, error_helpers.WrapError(err)
 	}
@@ -79,7 +79,7 @@ func (c *DbClient) ExecuteSyncInSession(ctx context.Context, session *db_common.
 // Execute implements Client
 // execute the query in the given Context
 // NOTE: The returned Result MUST be fully read - otherwise the connection will block and will prevent further communication
-func (c *DbClient) Execute(ctx context.Context, query string) (*queryresult.Result, error) {
+func (c *DbClient) Execute(ctx context.Context, query string, args ...any) (*queryresult.Result, error) {
 	// acquire a session
 	sessionResult := c.AcquireSession(ctx)
 	if sessionResult.Error != nil {
@@ -90,15 +90,15 @@ func (c *DbClient) Execute(ctx context.Context, query string) (*queryresult.Resu
 	c.setShouldShowTiming(ctx, sessionResult.Session)
 
 	// define callback to close session when the async execution is complete
-	closeSessionCallback := func() { sessionResult.Session.Close(utils.IsContextCancelled(ctx)) }
-	return c.ExecuteInSession(ctx, sessionResult.Session, query, closeSessionCallback)
+	closeSessionCallback := func() { sessionResult.Session.Close(error_helpers.IsContextCanceled(ctx)) }
+	return c.ExecuteInSession(ctx, sessionResult.Session, closeSessionCallback, query, args...)
 }
 
 // ExecuteInSession implements Client
 // execute the query in the given Context using the provided DatabaseSession
 // ExecuteInSession assumes no responsibility over the lifecycle of the DatabaseSession - that is the responsibility of the caller
 // NOTE: The returned Result MUST be fully read - otherwise the connection will block and will prevent further communication
-func (c *DbClient) ExecuteInSession(ctx context.Context, session *db_common.DatabaseSession, query string, onComplete func()) (res *queryresult.Result, err error) {
+func (c *DbClient) ExecuteInSession(ctx context.Context, session *db_common.DatabaseSession, onComplete func(), query string, args ...any) (res *queryresult.Result, err error) {
 	if query == "" {
 		return queryresult.NewResult(nil), nil
 	}
@@ -138,7 +138,7 @@ func (c *DbClient) ExecuteInSession(ctx context.Context, session *db_common.Data
 
 	// start query
 	var rows pgx.Rows
-	rows, err = c.startQuery(ctxExecute, query, session.Connection)
+	rows, err = c.startQuery(ctxExecute, session.Connection, query, args...)
 	if err != nil {
 		return
 	}
@@ -250,12 +250,12 @@ func (c *DbClient) updateScanMetadataMaxId(ctx context.Context, session *db_comm
 
 // run query in a goroutine, so we can check for cancellation
 // in case the client becomes unresponsive and does not respect context cancellation
-func (c *DbClient) startQuery(ctx context.Context, query string, conn *pgxpool.Conn) (rows pgx.Rows, err error) {
+func (c *DbClient) startQuery(ctx context.Context, conn *pgxpool.Conn, query string, args ...any) (rows pgx.Rows, err error) {
 	doneChan := make(chan bool)
 
 	go func() {
 		// start asynchronous query
-		rows, err = conn.Query(ctx, query)
+		rows, err = conn.Query(ctx, query, args...)
 		close(doneChan)
 	}()
 
@@ -327,18 +327,14 @@ func populateRow(columnValues []interface{}, cols []*queryresult.ColumnDef) ([]i
 	for i, columnValue := range columnValues {
 		if columnValue != nil {
 			result[i] = columnValue
-
 			switch cols[i].DataType {
 			case "_TEXT":
-				if arr, ok := columnValue.(pgtype.TextArray); ok {
-					strs := make([]string, len(arr.Elements))
-					for i, s := range arr.Elements {
-						strs[i] = s.String
-					}
-					result[i] = strings.Join(strs, ",")
+				if arr, ok := columnValue.([]interface{}); ok {
+					elements := utils.Map(arr, func(e interface{}) string { return e.(string) })
+					result[i] = strings.Join(elements, ",")
 				}
 			case "INET":
-				if inet, ok := columnValue.(*net.IPNet); ok {
+				if inet, ok := columnValue.(netip.Prefix); ok {
 					result[i] = strings.TrimSuffix(inet.String(), "/32")
 				}
 			case "UUID":
@@ -348,7 +344,9 @@ func populateRow(columnValues []interface{}, cols []*queryresult.ColumnDef) ([]i
 					}
 				}
 			case "TIME":
-				result[i] = time.UnixMilli(columnValue.(int64)).UTC().Format("15:04:05")
+				if t, ok := columnValue.(pgtype.Time); ok {
+					result[i] = time.UnixMicro(t.Microseconds).UTC().Format("15:04:05")
+				}
 			case "INTERVAL":
 				if interval, ok := columnValue.(pgtype.Interval); ok {
 					var sb strings.Builder
@@ -373,9 +371,8 @@ func populateRow(columnValues []interface{}, cols []*queryresult.ColumnDef) ([]i
 
 			case "NUMERIC":
 				if numeric, ok := columnValue.(pgtype.Numeric); ok {
-					var f float64
-					if err := numeric.AssignTo(&f); err == nil {
-						result[i] = f
+					if f, err := numeric.Float64Value(); err == nil {
+						result[i] = f.Float64
 					}
 				}
 			}
