@@ -9,16 +9,13 @@ import (
 	"os"
 	"os/exec"
 	"sync"
-	"time"
 
 	"github.com/fatih/color"
 	"github.com/jackc/pgx/v5"
-	"github.com/sethvargo/go-retry"
 	psutils "github.com/shirou/gopsutil/process"
 	filehelpers "github.com/turbot/go-kit/files"
 	"github.com/turbot/go-kit/helpers"
 	"github.com/turbot/steampipe/pkg/constants"
-	"github.com/turbot/steampipe/pkg/db/db_common"
 	"github.com/turbot/steampipe/pkg/filepaths"
 	"github.com/turbot/steampipe/pkg/ociinstaller"
 	"github.com/turbot/steampipe/pkg/ociinstaller/versionfile"
@@ -219,7 +216,7 @@ func prepareDb(ctx context.Context) error {
 		// get the message renderer from the context
 		// this allows the interactive client init to inject a custom renderer
 		messageRenderer := statushooks.MessageRendererFromContext(ctx)
-		messageRenderer("%s was updated to %s.", constants.Bold("steampipe-postgres-fdw"), constants.Bold(constants.FdwVersion))
+		messageRenderer("%s updated to %s.", constants.Bold("steampipe-postgres-fdw"), constants.Bold(constants.FdwVersion))
 	}
 
 	if needsInit() {
@@ -367,35 +364,6 @@ func resolveDatabaseName(oldDbName *string) string {
 	return databaseName
 }
 
-// createMaintenanceClient connects to the postgres server using the
-// maintenance database and superuser
-func createMaintenanceClient(ctx context.Context, port int) (*pgx.Conn, error) {
-	backoff := retry.NewConstant(200 * time.Millisecond)
-	var conn *pgx.Conn
-
-	err := retry.Do(ctx, retry.WithMaxRetries(5, backoff), func(ctx context.Context) error {
-		connStr := fmt.Sprintf("host=localhost port=%d user=%s dbname=postgres sslmode=disable", port, constants.DatabaseSuperUser)
-		log.Println("[TRACE] Connection string: ", connStr)
-		utils.LogTime("db_local.createClient connection open start")
-		connection, err := pgx.Connect(context.Background(), connStr)
-		utils.LogTime("db_local.createClient connection open end")
-		if err != nil {
-			return retry.RetryableError(err)
-		}
-		if err := db_common.WaitForConnection(ctx, connection); err != nil {
-			return retry.RetryableError(err)
-		}
-		conn = connection
-		return nil
-	})
-
-	if err != nil {
-		return nil, err
-	}
-
-	return conn, nil
-}
-
 func startServiceForInstall(port int) (*psutils.Process, error) {
 	postgresCmd := exec.Command(
 		getPostgresBinaryExecutablePath(),
