@@ -20,9 +20,8 @@ import (
 
 // LocalDbClient wraps over DbClient
 type LocalDbClient struct {
-	client        *db_client.DbClient
-	invoker       constants.Invoker
-	connectionMap *steampipeconfig.ConnectionDataMap
+	client  *db_client.DbClient
+	invoker constants.Invoker
 }
 
 // GetLocalClient starts service if needed and creates a new LocalDbClient
@@ -68,7 +67,7 @@ func NewLocalClient(ctx context.Context, invoker constants.Invoker, onConnection
 }
 
 // Close implements Client
-// close the connection to the database and shuts down the backend
+// close the connection to the database and shuts down the backend if we are the last connection
 func (c *LocalDbClient) Close(ctx context.Context) error {
 	log.Printf("[TRACE] close local client %p", c)
 	if c.client != nil {
@@ -88,13 +87,14 @@ func (c *LocalDbClient) ForeignSchemaNames() []string {
 	return c.client.ForeignSchemaNames()
 }
 
-// LoadForeignSchemaNames implements Client
-func (c *LocalDbClient) LoadForeignSchemaNames(ctx context.Context) error {
-	return c.client.LoadForeignSchemaNames(ctx)
+// AllSchemaNames implements Client
+func (c *LocalDbClient) AllSchemaNames() []string {
+	return c.client.AllSchemaNames()
 }
 
-func (c *LocalDbClient) ConnectionMap() *steampipeconfig.ConnectionDataMap {
-	return c.connectionMap
+// LoadSchemaNames implements Client
+func (c *LocalDbClient) LoadSchemaNames(ctx context.Context) error {
+	return c.client.LoadSchemaNames(ctx)
 }
 
 func (c *LocalDbClient) RefreshSessions(ctx context.Context) *db_common.AcquireSessionResult {
@@ -159,8 +159,8 @@ func (c *LocalDbClient) GetRequiredSessionSearchPath() []string {
 	return c.client.GetRequiredSessionSearchPath()
 }
 
-func (c *LocalDbClient) ContructSearchPath(ctx context.Context, requiredSearchPath, searchPathPrefix []string) ([]string, error) {
-	return c.client.ContructSearchPath(ctx, requiredSearchPath, searchPathPrefix)
+func (c *LocalDbClient) ConstructSearchPath(ctx context.Context, requiredSearchPath, searchPathPrefix []string) ([]string, error) {
+	return c.client.ConstructSearchPath(ctx, requiredSearchPath, searchPathPrefix)
 }
 
 // GetSchemaFromDB for LocalDBClient optimises the schema extraction by extracting schema
@@ -177,7 +177,7 @@ func (c *LocalDbClient) GetSchemaFromDB(ctx context.Context) (*schema.Metadata,
 	query := c.buildSchemasQuery(schemas)
 
 	acquireSessionResult := c.AcquireSession(ctx)
-	if acquireSessionResult.Error != nil {
+	if acquireSessionResult.Error != nil && acquireSessionResult.Session != nil {
 		acquireSessionResult.Session.Close(false)
 		return nil, err
 	}
@@ -258,37 +258,41 @@ WHERE %s
 	return query
 }
 
-// local only functions
-
 func (c *LocalDbClient) RefreshConnectionAndSearchPaths(ctx context.Context, forceUpdateConnectionNames ...string) *steampipeconfig.RefreshConnectionResult {
-	// NOTE: disable any status updates - we do not want 'loading' output from any queries
-	ctx = statushooks.DisableStatusHooks(ctx)
-
+	statushooks.SetStatus(ctx, "Refreshing connections")
 	res := c.refreshConnections(ctx, forceUpdateConnectionNames...)
 	if res.Error != nil {
 		return res
 	}
 
+	statushooks.SetStatus(ctx, "Setting up functions")
 	if err := refreshFunctions(ctx); err != nil {
 		res.Error = err
 		return res
 	}
 
+	statushooks.SetStatus(ctx, "Loading schema")
 	// reload the foreign schemas, in case they have changed
-	if err := c.LoadForeignSchemaNames(ctx); err != nil {
+	if err := c.LoadSchemaNames(ctx); err != nil {
 		res.Error = err
 		return res
 	}
 
+	statushooks.SetStatus(ctx, "Loading steampipe connections")
 	// load the connection state and cache it!
 	connectionMap, _, err := steampipeconfig.GetConnectionState(c.ForeignSchemaNames())
 	if err != nil {
 		res.Error = err
 		return res
 	}
-	c.connectionMap = &connectionMap
+	res.ConnectionMap = connectionMap
 	// set user search path first - client may fall back to using it
-	err = c.setUserSearchPath(ctx)
+	statushooks.SetStatus(ctx, "Setting up search path")
+
+	// we need to send a muted ctx here since this function selects from the database
+	// which by default puts up a "Loading" spinner. We don't want that here
+	mutedCtx := statushooks.DisableStatusHooks(ctx)
+	err = c.setUserSearchPath(mutedCtx)
 	if err != nil {
 		res.Error = err
 		return res
@@ -332,13 +336,15 @@ func (c *LocalDbClient) setUserSearchPath(ctx context.Context) error {
 
 	// get all roles which are a member of steampipe_users
 	query := fmt.Sprintf(`select usename from pg_user where pg_has_role(usename, '%s', 'member')`, constants.DatabaseUsersRole)
-	res, err := c.ExecuteSync(context.Background(), query)
+	res, err := c.ExecuteSync(ctx, query)
 	if err != nil {
 		return err
 	}
 
 	// set the search path for all these roles
-	var queries []string
+	var queries = []string{
+		"lock table pg_user;",
+	}
 	for _, row := range res.Rows {
 		rowResult := row.(*queryresult.RowResult)
 		user := string(rowResult.Data[0].(string))
@@ -351,9 +357,9 @@ func (c *LocalDbClient) setUserSearchPath(ctx context.Context) error {
 			strings.Join(escapedSearchPath, ","),
 		))
 	}
-	query = strings.Join(queries, "\n")
-	log.Printf("[TRACE] user search path sql: %s", query)
-	_, err = executeSqlAsRoot(ctx, query)
+
+	log.Printf("[TRACE] user search path sql: %v", queries)
+	_, err = executeSqlAsRoot(ctx, queries...)
 	if err != nil {
 		return err
 	}
