@@ -79,10 +79,11 @@ func StartServices(ctx context.Context, port int, listen StartListenType, invoke
 	if res.DbState == nil {
 		res = startDB(ctx, port, listen, invoker)
 	} else {
-		rootClient, err := createLocalDbClient(ctx, &CreateDbOptions{DatabaseName: res.DbState.Database, Username: constants.DatabaseSuperUser})
+		rootClient, err := CreateLocalDbConnection(ctx, &CreateDbOptions{DatabaseName: res.DbState.Database, Username: constants.DatabaseSuperUser})
 		if err != nil {
 			res.Error = err
 			res.Status = ServiceFailedToStart
+			return res
 		}
 		defer rootClient.Close(ctx)
 		// so db is already running - ensure it contains command schema
@@ -188,7 +189,6 @@ func startDB(ctx context.Context, port int, listen StartListenType, invoker cons
 		return res.SetError(err)
 	}
 
-	// sometimes connecting to the db immediately after startup results in a dial error - so retry
 	databaseName, err := getDatabaseName(ctx, port)
 	if err != nil {
 		return res.SetError(err)
@@ -221,7 +221,7 @@ func startDB(ctx context.Context, port int, listen StartListenType, invoker cons
 }
 
 func ensureService(ctx context.Context, databaseName string) error {
-	rootClient, err := createLocalDbClient(ctx, &CreateDbOptions{DatabaseName: databaseName, Username: constants.DatabaseSuperUser})
+	rootClient, err := CreateLocalDbConnection(ctx, &CreateDbOptions{DatabaseName: databaseName, Username: constants.DatabaseSuperUser})
 	if err != nil {
 		return err
 	}
@@ -311,7 +311,7 @@ func startPostgresProcess(ctx context.Context, port int, listen StartListenType,
 func retrieveDatabaseNameFromService(ctx context.Context, port int) (string, error) {
 	connection, err := createMaintenanceClient(ctx, port)
 	if err != nil {
-		return "", err
+		return "", fmt.Errorf("failed to connect to the database: %v - please try again or reset your steampipe database", err)
 	}
 	defer connection.Close(ctx)
 
@@ -426,12 +426,16 @@ func traceoutServiceLogs(logChannel chan string, stopLogStreamFn func()) {
 }
 
 func setServicePassword(ctx context.Context, password string) error {
-	connection, err := createLocalDbClient(ctx, &CreateDbOptions{DatabaseName: "postgres", Username: constants.DatabaseSuperUser})
+	connection, err := CreateLocalDbConnection(ctx, &CreateDbOptions{DatabaseName: "postgres", Username: constants.DatabaseSuperUser})
 	if err != nil {
 		return err
 	}
 	defer connection.Close(ctx)
-	_, err = connection.Exec(ctx, fmt.Sprintf(`alter user steampipe with password '%s'`, password))
+	statements := []string{
+		"lock table pg_user;",
+		fmt.Sprintf(`alter user steampipe with password '%s';`, password),
+	}
+	_, err = executeSqlInTransaction(ctx, connection, statements...)
 	return err
 }
 
@@ -491,7 +495,7 @@ func ensurePgExtensions(ctx context.Context, rootClient *pgx.Conn) error {
 		"ltree",
 	}
 
-	errors := []error{}
+	var errors []error
 	for _, extn := range extensions {
 		_, err := rootClient.Exec(ctx, fmt.Sprintf("create extension if not exists %s", db_common.PgEscapeName(extn)))
 		if err != nil {
@@ -519,15 +523,13 @@ func ensureSteampipeServer(ctx context.Context, rootClient *pgx.Conn) error {
 // create the command schema and grant insert permission
 func ensureCommandSchema(ctx context.Context, rootClient *pgx.Conn) error {
 	commandSchemaStatements := []string{
+		"lock table pg_namespace;",
 		getUpdateConnectionQuery(constants.CommandSchema, constants.CommandSchema),
 		fmt.Sprintf("grant insert on %s.%s to steampipe_users;", constants.CommandSchema, constants.CommandTableCache),
 		fmt.Sprintf("grant select on %s.%s to steampipe_users;", constants.CommandSchema, constants.CommandTableScanMetadata),
 	}
-
-	for _, statement := range commandSchemaStatements {
-		if _, err := rootClient.Exec(ctx, statement); err != nil {
-			return err
-		}
+	if _, err := executeSqlInTransaction(ctx, rootClient, commandSchemaStatements...); err != nil {
+		return err
 	}
 	return nil
 }
@@ -535,8 +537,11 @@ func ensureCommandSchema(ctx context.Context, rootClient *pgx.Conn) error {
 // ensures that the 'steampipe_users' role has permissions to work with temporary tables
 // this is done during database installation, but we need to migrate current installations
 func ensureTempTablePermissions(ctx context.Context, databaseName string, rootClient *pgx.Conn) error {
-	_, err := rootClient.Exec(ctx, fmt.Sprintf("grant temporary on database %s to %s", databaseName, constants.DatabaseUser))
-	if err != nil {
+	statements := []string{
+		"lock table pg_namespace;",
+		fmt.Sprintf("grant temporary on database %s to %s", databaseName, constants.DatabaseUser),
+	}
+	if _, err := executeSqlInTransaction(ctx, rootClient, statements...); err != nil {
 		return err
 	}
 	return nil
