@@ -375,10 +375,6 @@ func (i *ModInstaller) install(dependency *ResolvedModRef, parent *modconfig.Mod
 	if modDef == nil {
 		return nil, fmt.Errorf("'%s' has no mod definition file", dependency.FullName())
 	}
-	// hack set mod dependency path
-	if err := i.setModDependencyPath(modDef, i.tmpPath); err != nil {
-		return nil, err
-	}
 
 	// so we have successfully installed this dependency to the temp location, now copy to the mod location
 	if !i.dryRun {
@@ -386,6 +382,10 @@ func (i *ModInstaller) install(dependency *ResolvedModRef, parent *modconfig.Mod
 		if err := i.copyModFromTempToModsFolder(tempDestPath, destPath); err != nil {
 			return nil, err
 		}
+		// now the mod is installed in it's final location, set mod dependency path
+		if err := i.setModDependencyPath(modDef, destPath); err != nil {
+			return nil, err
+		}
 	}
 
 	return modDef, nil
