@@ -1,7 +1,6 @@
 package queryresult
 
 import (
-	"database/sql"
 	"time"
 )
 
@@ -21,34 +20,37 @@ type RowResult struct {
 }
 type Result struct {
 	RowChan      *chan *RowResult
-	ColTypes     []*sql.ColumnType
+	Cols         []*ColumnDef
 	TimingResult chan *TimingResult
 }
 
-// Close closes the row channel
-func (r Result) Close() {
-	close(*r.RowChan)
-}
+func NewResult(cols []*ColumnDef) *Result {
 
-func (r Result) StreamRow(rowResult []interface{}) {
-	*r.RowChan <- &RowResult{Data: rowResult}
-}
-
-func (r Result) StreamError(err error) {
-	*r.RowChan <- &RowResult{Error: err}
-}
-
-func NewQueryResult(colTypes []*sql.ColumnType) *Result {
 	rowChan := make(chan *RowResult)
 	return &Result{
 		RowChan:      &rowChan,
-		ColTypes:     colTypes,
+		Cols:         cols,
 		TimingResult: make(chan *TimingResult, 1),
 	}
 }
 
+// IsExportSourceData implements ExportSourceData
+func (*Result) IsExportSourceData() {}
+
+// Close closes the row channel
+func (r *Result) Close() {
+	close(*r.RowChan)
+}
+
+func (r *Result) StreamRow(rowResult []interface{}) {
+	*r.RowChan <- &RowResult{Data: rowResult}
+}
+func (r *Result) StreamError(err error) {
+	*r.RowChan <- &RowResult{Error: err}
+}
+
 type SyncQueryResult struct {
 	Rows         []interface{}
-	ColTypes     []*sql.ColumnType
+	Cols         []*ColumnDef
 	TimingResult *TimingResult
 }
