@@ -7,7 +7,6 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/hashicorp/hcl/v2"
 	"github.com/turbot/steampipe/pkg/filepaths"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/options"
@@ -66,24 +65,6 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 							Byte:   10,
 						},
 					},
-					LegacyName:            "",
-					LegacyPluginShortName: "",
-					LegacyPlugin:          "",
-					LegacyType:            "",
-					LegacyConfig:          "",
-					LegacyDeclRange: hcl.Range{
-						Filename: "",
-						Start: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-						End: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-					},
 				},
 				"aws_dmi_002": {
 					Name:            "aws_dmi_002",
@@ -104,24 +85,6 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 							Byte:   10,
 						},
 					},
-					LegacyName:            "",
-					LegacyPluginShortName: "",
-					LegacyPlugin:          "",
-					LegacyType:            "",
-					LegacyConfig:          "",
-					LegacyDeclRange: hcl.Range{
-						Filename: "",
-						Start: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-						End: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-					},
 				},
 			},
 			DefaultConnectionOptions: &options.Connection{
@@ -153,24 +116,6 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 							Byte:   10,
 						},
 					},
-					LegacyName:            "",
-					LegacyPluginShortName: "",
-					LegacyPlugin:          "",
-					LegacyType:            "",
-					LegacyConfig:          "",
-					LegacyDeclRange: hcl.Range{
-						Filename: "",
-						Start: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-						End: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-					},
 				},
 			},
 			DefaultConnectionOptions: &options.Connection{
@@ -202,24 +147,6 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 							Byte:   10,
 						},
 					},
-					LegacyName:            "",
-					LegacyPluginShortName: "",
-					LegacyPlugin:          "",
-					LegacyType:            "",
-					LegacyConfig:          "",
-					LegacyDeclRange: hcl.Range{
-						Filename: "",
-						Start: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-						End: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-					},
 				},
 			},
 			DefaultConnectionOptions: &options.Connection{
@@ -274,24 +201,6 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 							Byte:   10,
 						},
 					},
-					LegacyName:            "",
-					LegacyPluginShortName: "",
-					LegacyPlugin:          "",
-					LegacyType:            "",
-					LegacyConfig:          "",
-					LegacyDeclRange: hcl.Range{
-						Filename: "",
-						Start: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-						End: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-					},
 				},
 			},
 			DefaultConnectionOptions: &options.Connection{
@@ -342,24 +251,6 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 							Byte:   10,
 						},
 					},
-					LegacyName:            "",
-					LegacyPluginShortName: "",
-					LegacyPlugin:          "",
-					LegacyType:            "",
-					LegacyConfig:          "",
-					LegacyDeclRange: hcl.Range{
-						Filename: "",
-						Start: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-						End: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-					},
 				},
 			},
 			DefaultConnectionOptions: &options.Connection{
@@ -412,24 +303,6 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 							Byte:   10,
 						},
 					},
-					LegacyName:            "",
-					LegacyPluginShortName: "",
-					LegacyPlugin:          "",
-					LegacyType:            "",
-					LegacyConfig:          "",
-					LegacyDeclRange: hcl.Range{
-						Filename: "",
-						Start: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-						End: hcl.Pos{
-							Line:   0,
-							Column: 0,
-							Byte:   0,
-						},
-					},
 				},
 			},
 			DefaultConnectionOptions: &options.Connection{
