@@ -2,6 +2,7 @@ package modconfig
 
 import (
 	"fmt"
+	"github.com/zclconf/go-cty/cty"
 	"sort"
 	"strings"
 
@@ -9,48 +10,41 @@ import (
 	"github.com/turbot/go-kit/types"
 	typehelpers "github.com/turbot/go-kit/types"
 	"github.com/turbot/steampipe/pkg/utils"
-	"github.com/zclconf/go-cty/cty"
 )
 
 // Benchmark is a struct representing the Benchmark resource
 type Benchmark struct {
-	ResourceWithMetadataBase
+	ResourceWithMetadataImpl
+	ModTreeItemImpl
 
-	ShortName       string `json:"-"`
-	FullName        string `cty:"name" json:"-"`
-	UnqualifiedName string `json:"-"`
+	// required to allow partial decoding
+	Remain hcl.Body `hcl:",remain" json:"-"`
 
 	// child names as NamedItem structs - used to allow setting children via the 'children' property
 	ChildNames NamedItemList `cty:"child_names" json:"-"`
 	// used for introspection tables
 	ChildNameStrings []string `cty:"child_name_strings" column:"children,jsonb" json:"-"`
-	// the actual children
-	Children      []ModTreeItem     `json:"-"`
-	Description   *string           `cty:"description" hcl:"description" column:"description,text" json:"-"`
-	Documentation *string           `cty:"documentation" hcl:"documentation" column:"documentation,text" json:"-"`
-	Tags          map[string]string `cty:"tags" hcl:"tags,optional" column:"tags,jsonb" json:"-"`
-	Title         *string           `cty:"title" hcl:"title" column:"title,text" json:"-"`
 
 	// dashboard specific properties
 	Base    *Benchmark `hcl:"base" json:"-"`
 	Width   *int       `cty:"width" hcl:"width" column:"width,text" json:"-"`
 	Type    *string    `cty:"type" hcl:"type" column:"type,text" json:"-"`
 	Display *string    `cty:"display" hcl:"display" json:"-"`
-
-	References []*ResourceReference `json:"-"`
-	Mod        *Mod                 `cty:"mod" json:"-"`
-	DeclRange  hcl.Range            `json:"-"`
-	Paths      []NodePath           `column:"path,jsonb" json:"-"`
-	Parents    []ModTreeItem        `json:"-"`
 }
 
 func NewBenchmark(block *hcl.Block, mod *Mod, shortName string) HclResource {
+	fullName := fmt.Sprintf("%s.%s.%s", mod.ShortName, block.Type, shortName)
 	benchmark := &Benchmark{
-		ShortName:       shortName,
-		FullName:        fmt.Sprintf("%s.benchmark.%s", mod.ShortName, shortName),
-		UnqualifiedName: fmt.Sprintf("benchmark.%s", shortName),
-		Mod:             mod,
-		DeclRange:       block.DefRange,
+		ModTreeItemImpl: ModTreeItemImpl{
+			HclResourceImpl: HclResourceImpl{
+				ShortName:       shortName,
+				FullName:        fullName,
+				UnqualifiedName: fmt.Sprintf("%s.%s", block.Type, shortName),
+				DeclRange:       block.DefRange,
+				blockType:       block.Type,
+			},
+			Mod: mod,
+		},
 	}
 	benchmark.SetAnonymous(block)
 	return benchmark
@@ -64,51 +58,21 @@ func (b *Benchmark) Equals(other *Benchmark) bool {
 	return !b.Diff(other).HasChanges()
 }
 
-// CtyValue implements HclResource
-func (b *Benchmark) CtyValue() (cty.Value, error) {
-	return getCtyValue(b)
-}
-
-// GetDeclRange implements HclResource
-func (b *Benchmark) GetDeclRange() *hcl.Range {
-	return &b.DeclRange
-}
-
-// BlockType implements HclResource
-func (*Benchmark) BlockType() string {
-	return BlockTypeBenchmark
-}
-
 // OnDecoded implements HclResource
 func (b *Benchmark) OnDecoded(block *hcl.Block, resourceMapProvider ResourceMapsProvider) hcl.Diagnostics {
-	b.setBaseProperties(resourceMapProvider)
+	b.setBaseProperties()
 	return nil
 }
 
-// AddReference implements ResourceWithMetadata
-func (b *Benchmark) AddReference(ref *ResourceReference) {
-	b.References = append(b.References, ref)
-}
-
-// GetReferences implements ResourceWithMetadata
-func (b *Benchmark) GetReferences() []*ResourceReference {
-	return b.References
-}
-
-// GetMod implements ModTreeItem
-func (b *Benchmark) GetMod() *Mod {
-	return b.Mod
-}
-
 func (b *Benchmark) String() string {
 	// build list of children's names
 	var children []string
-	for _, child := range b.Children {
+	for _, child := range b.children {
 		children = append(children, child.Name())
 	}
 	// build list of parents names
 	var parents []string
-	for _, p := range b.Parents {
+	for _, p := range b.parents {
 		parents = append(parents, p.Name())
 	}
 	sort.Strings(children)
@@ -131,7 +95,7 @@ func (b *Benchmark) String() string {
 // GetChildControls return a flat list of controls underneath the benchmark in the tree
 func (b *Benchmark) GetChildControls() []*Control {
 	var res []*Control
-	for _, child := range b.Children {
+	for _, child := range b.children {
 		if control, ok := child.(*Control); ok {
 			res = append(res, control)
 		} else if benchmark, ok := child.(*Benchmark); ok {
@@ -141,65 +105,6 @@ func (b *Benchmark) GetChildControls() []*Control {
 	return res
 }
 
-// AddParent implements ModTreeItem
-func (b *Benchmark) AddParent(parent ModTreeItem) error {
-	b.Parents = append(b.Parents, parent)
-	return nil
-}
-
-// GetParents implements ModTreeItem
-func (b *Benchmark) GetParents() []ModTreeItem {
-	return b.Parents
-}
-
-// GetTitle implements HclResource
-func (b *Benchmark) GetTitle() string {
-	return typehelpers.SafeString(b.Title)
-}
-
-// GetDescription implements ModTreeItem, DashboardLeafNode
-func (b *Benchmark) GetDescription() string {
-	return typehelpers.SafeString(b.Description)
-}
-
-// GetTags implements HclResource, DashboardLeafNode
-func (b *Benchmark) GetTags() map[string]string {
-	if b.Tags != nil {
-		return b.Tags
-	}
-	return map[string]string{}
-}
-
-// GetChildren implements ModTreeItem
-func (b *Benchmark) GetChildren() []ModTreeItem {
-	return b.Children
-}
-
-// GetPaths implements ModTreeItem
-func (b *Benchmark) GetPaths() []NodePath {
-	// lazy load
-	if len(b.Paths) == 0 {
-		b.SetPaths()
-	}
-
-	return b.Paths
-}
-
-// SetPaths implements ModTreeItem
-func (b *Benchmark) SetPaths() {
-	for _, parent := range b.Parents {
-		for _, parentPath := range parent.GetPaths() {
-			b.Paths = append(b.Paths, append(parentPath, b.Name()))
-		}
-	}
-}
-
-// Name implements ModTreeItem, HclResource, ResourceWithMetadata
-// return name in format: '<modname>.control.<shortName>'
-func (b *Benchmark) Name() string {
-	return b.FullName
-}
-
 // GetWidth implements DashboardLeafNode
 func (b *Benchmark) GetWidth() int {
 	if b.Width == nil {
@@ -213,11 +118,6 @@ func (b *Benchmark) GetDisplay() string {
 	return typehelpers.SafeString(b.Display)
 }
 
-// GetDocumentation implements DashboardLeafNode, ModTreeItem
-func (b *Benchmark) GetDocumentation() string {
-	return typehelpers.SafeString(b.Documentation)
-}
-
 // GetType implements DashboardLeafNode
 func (b *Benchmark) GetType() string {
 	return typehelpers.SafeString(b.Type)
@@ -274,7 +174,7 @@ func (b *Benchmark) Diff(other *Benchmark) *DashboardTreeItemDiffs {
 }
 
 func (b *Benchmark) WalkResources(resourceFunc func(resource ModTreeItem) (bool, error)) error {
-	for _, child := range b.Children {
+	for _, child := range b.children {
 		continueWalking, err := resourceFunc(child)
 		if err != nil {
 			return err
@@ -292,39 +192,34 @@ func (b *Benchmark) WalkResources(resourceFunc func(resource ModTreeItem) (bool,
 	return nil
 }
 
-func (b *Benchmark) setBaseProperties(resourceMapProvider ResourceMapsProvider) {
-	// not all base properties are stored in the evalContext
-	// (e.g. resource metadata and runtime dependencies are not stores)
-	//  so resolve base from the resource map provider (which is the RunContext)
-	if base, resolved := resolveBase(b.Base, resourceMapProvider); !resolved {
+func (b *Benchmark) SetChildren(children []ModTreeItem) {
+	b.children = children
+}
+
+// CtyValue implements CtyValueProvider
+func (b *Benchmark) CtyValue() (cty.Value, error) {
+	return GetCtyValue(b)
+}
+
+func (b *Benchmark) setBaseProperties() {
+	if b.Base == nil {
 		return
-	} else {
-		b.Base = base.(*Benchmark)
 	}
+	// copy base into the HclResourceImpl 'base' property so it is accessible to all nested structs
+	b.base = b.Base
+	// call into parent nested struct setBaseProperties
+	b.ModTreeItemImpl.setBaseProperties()
 
-	if b.Description == nil {
-		b.Description = b.Base.Description
-	}
-
-	if b.Documentation == nil {
-		b.Documentation = b.Base.Documentation
-	}
-
-	if b.Type == nil {
-		b.Type = b.Base.Type
+	if b.Width == nil {
+		b.Width = b.Base.Width
 	}
 
 	if b.Display == nil {
 		b.Display = b.Base.Display
 	}
 
-	b.Tags = utils.MergeMaps(b.Tags, b.Base.Tags)
-	if b.Title == nil {
-		b.Title = b.Base.Title
-	}
-
-	if len(b.Children) == 0 {
-		b.Children = b.Base.Children
+	if len(b.children) == 0 {
+		b.children = b.Base.children
 		b.ChildNameStrings = b.Base.ChildNameStrings
 		b.ChildNames = b.Base.ChildNames
 	}
